CHANGELOG
=========

1.2.1 - 2025-03-23
------------------

Add title to Bluesky

Contributed by [Daniel Lemos](https://github.com/xspager) via [PR #34](https://github.com/pelican-plugins/share-post/pull/34/)


1.2.0 - 2025-01-29
------------------

Add Bluesky support

Contributed by [Leonardo Giordani](https://github.com/lgiordani) via [PR #33](https://github.com/pelican-plugins/share-post/pull/33/)


1.1.0 - 2023-08-31
------------------

Add Mastodon share link

1.0.0 - 2021-03-19
------------------

Initial release as namespace plugin

[Justin Mayer](https://github.com/justinmayer) [PR #1](https://github.com/pelican-plugins/share-post/pull/1/)
